﻿using System;
using System.Windows.Forms;
using MediaPortal.GUI.Library;
using MediaPortal.Dialogs;

namespace $safeprojectname$
{
    /// --------------------------------------------------------------------------------
    /// <summary>
    /// Media Portal PlugIn - ???
    /// </summary>
    /// 
    /// <remarks>
    /// Provides an interface to ...
    /// </remarks>
    /// 
    /// <revisionHistory>
    ///		<revision date="2009/03/10" version="1.0.0.0" author="$username$">
    ///			Initial Version.
    ///		</revision>
    /// </revisionHistory>
    /// --------------------------------------------------------------------------------
    public class PluginGUI : GUIWindow, ISetupForm
    {

        #region ISetupForm Members

        /// <summary>
        /// Returns the name of the plugin, which is shown in the plugin menu. 
        /// </summary>
        public string PluginName()
        {
            return "$safeprojectname$";
        }


        /// <summary>
        /// Returns the description of the plugin, which is shown in the plugin menu. 
        /// </summary>
        public string Description()
        {
            return "My GUI Plugin Description";
        }


        /// <summary>
        /// Returns the author of the plugin, which is shown in the plugin menu. 
        /// </summary>
        public string Author()
        {
            return "$username$";
        }


        /// <summary>
        /// Shows the setup dialog. 
        /// </summary>
        public void ShowPlugin()
        {
            try
            {
                MessageBox.Show("Nothing to configure, this is just an example");
            }
            catch (Exception ex)
            {
                // You could log something here if you want.

                // pass exception on thru.
                throw;
            }
        }


        /// <summary>
        /// Indicates whether the plugin can be enabled / disabled.
        /// </summary>
        /// <returns></returns>
        public bool CanEnable()
        {
            return true;
        }


        /// <summary>
        /// Returns the unique WindowID beloging to this plugin.
        /// </summary>
        /// <returns></returns>
        public int GetWindowId()
        {
            return 5678;
        }


        /// <summary>
        /// Indicates if plugin is enabled by default (true) or not (false). 
        /// </summary>
        /// <returns></returns>
        public bool DefaultEnabled()
        {

            return true;

        }


        /// <summary>
        /// Indicates if a plugin has it's own setup screen (true) or not (false). 
        /// </summary>
        public bool HasSetup()
        {
            return true;
        }


        /// <summary>
        /// If the plugin should have it's own button on the main menu of MediaPortal then it
        /// should return true to this method; otherwise, return false to not show on the home menu.
        /// </summary>  
        /// <param name="buttonText">text the button should have</param>  
        /// <param name="buttonImage">image for the button, or empty for default</param>  
        /// <param name="buttonImageFocus">image for the button, or empty for default</param>  
        /// <param name="pictureImage">subpicture for the button or empty for none</param>  
        /// <returns>true : plugin needs it's own button on home  
        /// false : plugin does not need it's own button on home</returns>  
        public bool GetHome(out string buttonText, out string buttonImage, out string buttonImageFocus, out string pictureImage)
        {
            try
            {
                // set home button parameters.
                bool showInHome = true;
                buttonText = this.PluginName();
                buttonImage = String.Empty;
                buttonImageFocus = String.Empty;
                pictureImage = GUIGraphicsContext.Skin + @"\Media\hover_my plugins.png";

                // return to caller.
                return showInHome;
            }
            catch (Exception ex)
            {
                // You could log something here if you want.

                // pass exception on thru.
                throw;
            }
        }



        /// <summary>
        /// Gets the unique window ID.
        /// </summary>
        /// <remarks>
        /// With GetID it will be an window-plugin / otherwise a process-plugin.
        /// </remarks>
        public override int GetID
        {
            get
            {
                return this.GetWindowId();
            }
            set
            {
            }
        }

        #endregion


        /// <summary>
        /// Initializes a new instance of the class.
        /// </summary>
        /// <returns>True if the plugin was initialized; otherwise, false.</returns>
        public override bool Init()
        {
            try
            {
                // formulate skin file path.
                string skinpath = GUIGraphicsContext.Skin + @"\$safeprojectname$Main.xml";

                // load plugin skin file.
                return Load(skinpath);
            }
            catch (Exception ex)
            {
                // You could log something here if you want.

                // pass exception on thru.
                throw;
            }
        }


        /// <summary>
        /// GUI Button control (ID=2).
        /// </summary>
        [SkinControlAttribute(2)]
        protected GUIButtonControl buttonOne = null;

        /// <summary>
        /// GUI Button control (ID=3).
        /// </summary>
        [SkinControlAttribute(3)]
        protected GUIButtonControl buttonTwo = null;

        /// <summary>
        /// Process a skin click event.
        /// </summary>
        /// <param name="controlId">Unique ID of the control.</param>
        /// <param name="control">Control object.</param>
        /// <param name="actionType">Type of action requested.</param>
        protected override void OnClicked(int controlId, GUIControl control, Action.ActionType actionType)
        {
            try
            {
                // process button click event.
                if (control == buttonOne)
                    OnButtonOne();
                else if (control == buttonTwo)
                    OnButtonTwo();
            }
            catch (Exception ex)
            {
                // You could log something here if you want.

                // pass exception on thru.
                throw;
            }
            finally
            {
                // invoke base class method.
                base.OnClicked(controlId, control, actionType);
            }
        }


        /// <summary>
        /// Process button click event.
        /// </summary>
        private void OnButtonOne()
        {
            GUIDialogOK dlg = (GUIDialogOK)GUIWindowManager.GetWindow((int)GUIWindow.Window.WINDOW_DIALOG_OK);
            dlg.SetHeading("Button has been pressed");
            dlg.SetLine(1, "You pressed button 1");
            dlg.SetLine(2, String.Empty);
            dlg.SetLine(3, String.Empty);
            dlg.DoModal(GUIWindowManager.ActiveWindow);
        }


        /// <summary>
        /// Process button click event.
        /// </summary>
        private void OnButtonTwo()
        {
            GUIDialogOK dlg = (GUIDialogOK)GUIWindowManager.GetWindow((int)GUIWindow.Window.WINDOW_DIALOG_OK);
            dlg.SetHeading("Button has been pressed");
            dlg.SetLine(1, "You pressed button 2");
            dlg.SetLine(2, String.Empty);
            dlg.SetLine(3, String.Empty);
            dlg.DoModal(GUIWindowManager.ActiveWindow);
        }
    }
}
